Learn R Programming

sca (version 0.9-0)

allcrit: Simple Component Quality Criterion Computation

Description

Compute simple component criterion for components P on cor.matrix S (cumulative), using sccrit().

Function allcrit() computes even more criteria, some derived from sccrit().

Usage

allcrit(S, P, criterion, sortP = TRUE) sccrit(S, P, criterion, sortP = TRUE)

Arguments

S
correlation/covariance matrix
P
component matrix
criterion
character string specifying the optimality criterion to be used in sccrit() for evaluating a system of simple components. One of "csv" (corrected sum of variances) or "blp" (best linear predictor).
sortP
logical indicating if P should be sorted; if true, sortmatrix(S,P) used in lieu of P.

Value

sccrit() returns a numeric vector, the criterion computed (cumulatively).allcrit() returns a list with components varpc, varsc, cumpc, cumsc, opt, corsc, and maxcor; see the description of the allcrit component in the return value of sca().

See Also

quickcrit, sca, also for references.