Learn R Programming

sca (version 0.9-0)

quickcrit: Additional Contribution of New Component to the SC System

Description

Compute the additional contribution of a new component to the simple component system P on S.

Usage

quickcrit(newcomp, S, P, criterion)

Arguments

newcomp
numeric vector, typically the result of simpvector().
S
correlation/covariance matrix
P
component matrix
criterion
character string specifying the optimality criterion, see sccrit for details.

Value

...

See Also

sccrit; further sca, also for references.